@@ -3,10 +3,11 @@ package Yote;
 use strict;
 use warnings;
 no  warnings 'uninitialized';
+use Module::Loaded;
 
 use vars qw($VERSION);
 
-$VERSION = '1.37';
+$VERSION = '1.38';
 
 =head1 NAME
 
@@ -147,11 +148,11 @@ no warnings 'uninitialized';
 no warnings 'recursion';
 
 use WeakRef;
-
+use Module::Loaded;
 
 use vars qw($VERSION);
 
-$VERSION = '1.37';
+$VERSION = '1.38';
 
 =head1 NAME
 
@@ -253,8 +254,10 @@ sub fetch {
             my $obj;
             eval {
                 my $path = $class;
-                $path =~ s!::!/!g;
-                $INC{"${path}.pm"} || eval("require $class");
+                unless( is_loaded( $class ) ) {
+                    eval("require $class");
+                    mark_as_loaded( $class );
+                }
                 $obj = $class->_instantiate( $id, $self );
             };
             die $@ if $@;
@@ -322,6 +325,9 @@ sub _new { #Yote::ObjStore
 
 sub _init {
     my $self = shift;
+    for my $pkg ( qw( Yote::Obj Yote::Array Yote::Hash ) ) {
+        is_loaded( $pkg ) or mark_as_loaded( $pkg );
+    }
     $self->fetch_root;
     $self->stow_all;
     $self;
@@ -573,7 +579,7 @@ no  warnings 'uninitialized';
 
 use vars qw($VERSION);
 
-$VERSION = '1.37';
+$VERSION = '1.38';
 
 #
 # The string version of the yote object is simply its id. This allows
@@ -842,7 +848,7 @@ use Tie::Array;
 
 use vars qw($VERSION);
 
-$VERSION = '1.37';
+$VERSION = '1.38';
 
 sub TIEARRAY {
     my( $class, $obj_store, $id, @list ) = @_;
@@ -937,7 +943,7 @@ use Tie::Hash;
 
 use vars qw($VERSION);
 
-$VERSION = '1.37';
+$VERSION = '1.38';
 
 sub TIEHASH {
     my( $class, $obj_store, $id, %hash ) = @_;
@@ -1014,7 +1020,7 @@ use constant {
 
 use vars qw($VERSION);
 
-$VERSION = '1.37';
+$VERSION = '1.38';
 
 #
 # This the main index and stores in which table and position
@@ -1198,6 +1204,6 @@ __END__
        under the same terms as Perl itself.
 
 =head1 VERSION
-       Version 1.37  (May 5, 2016))
+       Version 1.38  (May 9, 2016))
 
 =cut
